# -*- coding: UTF-8 -*-
"""
Created on
"""
from tqdm import tqdm
from json import loads
from aitool import timestamp, dump_excel, load_lines, AutoPrompt
from random import sample


def get_dataset():
    # 开源数据来源：https://github.com/thunlp/CAIL/blob/master/README_en.md
    raw_data = load_lines('r8_task_backup/autoprompt/tool/CAIL2018/first_stage/train.json')
    multilabel_data = []
    xx = set()
    for line in tqdm(raw_data):
        line = loads(line)
        case_input_ori = line['fact']
        case_input = '\n'.join([paragraph[:10000] for paragraph in case_input_ori.split('\r\n')])
        labels = []
        for label in line['meta']['accusation']:
            labels.append(label.replace('、', ''))
        if line['meta']['term_of_imprisonment']['life_imprisonment']:
            labels.append('无期徒刑')
        if line['meta']['term_of_imprisonment']['death_penalty']:
            labels.append('死刑')
        for x in labels:
            xx.add(x)
        if len(labels) < 2:
            continue
        multilabel_data.append(('，'.join(labels), 'good', case_input, ''))
    dump_excel(multilabel_data, './CAIL2018/multi_label.xlsx')
    train_data = sample(multilabel_data[:1000], 20)
    test_data = sample(multilabel_data[1000:], 100)
    return train_data, test_data


if __name__ == '__main__':
    re_sample = True
    if re_sample:
        data_train, data_test = get_dataset()
    else:
        data_train = [('抢劫，盗窃', 'good', '经审理查明：\n2015年7月12日20时许，被告人李某至常州市武进区礼嘉镇北京联华超市二楼移动营业厅，在购买手机过\n上述事实，被告人李某当庭无异议，并有被害人王某的陈述笔录，证人马某、童某、孙某的证言笔录，销售凭证、\n', ''), ('故意伤害，无期徒刑', 'good', '湖北省孝感市人民检察院指控：2012年7月，孝某籍女青年肖某与被告人李1某同在孝某县古城大道“简朴田\n为证实上述指控的事实，公诉机关当庭宣读了现场勘验检查笔录、司法鉴定书、证人证言、被告人供述，并出示了\n附带民事诉讼原告人李某甲、王某甲要求被告人李1某赔偿丧葬费16025元、死亡赔偿金367480元、被\n', ''), ('盗窃，走私贩卖运输制造毒品', 'good', '经审理查明：\n一、盗窃犯罪事实\n2016年1月18日11时许，被告人彭某某与张某某（另案处理）共谋扒窃后，来到重庆市永川区玉屏菜市场\n2016年6月17日15时许，被告人彭某某在重庆市永川区东岳桥农贸市场一茶馆内被公安民警抓获，其到案\n案发后，张某某赔偿了被害人苏某某损失并取得了谅解。\n2016年7月13日，彭某某在监视居住期间配合公安民警将涉嫌贩卖毒品的陈某抓获，民警当场从陈某处查获\n上述事实，被告人彭某某在开庭审理中亦无异议，且当庭认罪，并有受案登记表、立案决定书、抓获经过、常住人\n二、贩卖毒品犯罪事实\n2016年9月1日15时许，被告人彭某某在监视居住期间接到吸毒人员侯某要求购买600元毒品海洛因的电\n上述事实，被告人彭某某在开庭审理中亦无异议，且当庭认罪，并有受案登记表、立案决定书、抓获经过、常住人\n', ''), ('故意伤害，无期徒刑', 'good', '武汉市人民检察院指控：2002年4月11日零时许，曾某乙在本市武昌区中华路青龙巷“花中花”发廊店，与\n公诉机关当庭出示的证据：1、破案及抓获经过；2、法医检验报告等鉴定意见；3、现场勘查笔录及现场照片；\n公诉机关认为，被告人王1某无视国法，因琐事与他人发生矛盾后，竟持械故意伤害他人身体，造成一人死亡的严\n附带民事诉讼原告人曾某甲、付某要求被告人王1某赔偿死亡赔偿金人民币458120元、丧葬费人民币231\n', ''), ('故意伤害，无期徒刑', 'good', '广东省佛山市人民检察院指控，2015年8月27日晚，被告人何某想和被害人韦某子、韦某乙（另案处理）等\n针对指控的犯罪事实，公诉机关在庭上提供了相应的证据，并据此认为被告人何某想的行为已触犯《中华人民共和\n', ''), ('拐卖妇女儿童，诈骗', 'good', '清丰县人民检察院指控，2005年11月11日，被告人程2某伙同他人将清丰县柳格乡五眼井村刘某某（本名\n', ''), ('虚开增值税专用发票用于骗取出口退税抵扣税款发票，死刑', 'good', '经审理查明，2010年6月至7月，被告人郭某在担任个人独资企业上海某某厂负责人期间，为非法抵扣税款，\n另查明，2013年10月21日，被告人郭某主动至公安机关投案，并如实供述了上述事实。案发后，上海某某\n还查明，被告人郭某曾于2012年12月因犯虚开增值税专用发票罪被上海市杨浦区人民法院判处××，××。\n上述事实，被告人郭某在开庭审理过程中亦无异议，且有其供述笔录，证人陈某的证言笔录，上海增值税专用发票\n', ''), ('盗窃，无期徒刑', 'good', '公诉机关指控：2015年2月8日，被告人吴某某至上海市奉贤区奉浦社区发展村11组被害人陈某住处，撞门\n案发后，上述被窃物品均已被扣押并发还被害人。\n', ''), ('盗窃，诈骗', 'good', '兴山县人民检察院指控，2012年11月，被告人胡某对宋某某、秦某某、余某甲等人谎称自己在宜巴高速承包\n公诉机关认为被告人胡某的行为构成××，建议判处五年以上七年以下××，并处罚金。\n公诉机关向法庭提交了以下证据材料：\n（一）物证。鄂E×××××别克牌SGM6510GL8商务车一辆（含车钥匙一套），苹果电脑一体机、键盘\n（二）书证。受案登记表，余某甲书写的报案材料，到案经过，向某乙的农业银行卡某对账单及账户明细查询，胡\n（三）证人田某某、鲁某、陈某某、李某某、宋某某、张某、向某甲、沈某某的证言。\n（四）被害人余某甲、秦某某的陈述。\n（五）被告人胡某的供述及讯问同步录音录像。\n', ''), ('制造贩卖传播淫秽物品，传播淫秽物品', 'good', '德州市德城区人民检察院指控，“2016年2月份以来，被告人吴某在互联网上利用号码为860295449\n公诉人在庭审中称，被告人吴某主观恶性不深，社会危害性相对较小；吴某认罪态度较好。\n', ''), ('抢劫，盗窃', 'good', '经审理查明，（一）××\n1、2013年9月19日12时许，被告人金某伙同王某甲、贾某到诸城市程戈庄到浩仉村的路上，采用棒球棍\n2、2013年9月21日12时许，被告人金某伙同王某甲、贾某到诸城市孟疃邮局附近，采用棒球棍威胁等手\n（二）××\n2013年9月，被告人金某与王某甲、贾某、陈某（均未满14周岁）交叉结伙到诸城市水上公园、程戈庄等地\n1、2013年9月7日18时许，被告人金某伙同王某甲、贾某、陈某到诸城市水上公园北停车场，盗窃谭某的\n2、2013年9月15日20时许，被告人金某伙同王某甲、贾某到诸城市水上公园北停车场，盗窃庄某鲁L×\n3、2013年9月的一天，被告人金某伙同王某甲、贾某到诸城市舜王街道程戈庄四村陈某家门口处，盗窃25\n4、2013年9月的一天，被告人金某伙同王某甲、贾某到诸城市解留水管站西，盗窃丁某的12L汽油，价值\n上述事实，有物证指认现场照片、被盗物品照片，书证户籍证明、报警记录、办案说明、抓获经过、诸城市公安局\n', ''), ('故意伤害，非法拘禁', 'good', '经审理查明，2013年4月份，杨某某（已判刑）在李某某和尚某某（身份不详）开的赌场赌博时欠下赌债，尚\n2013年5月16日19时许，晏某某、覃2某、彭某丙、雷某等人从龙山县农车乡回龙山县城途径县城一三岔\n另查明，被告人张2某于2015年2月22日被永顺县公安局巡警大队抓获归案。因犯××2014年3月8日\n上述事实，被告人在庭审中亦无异议，并有经庭审中质证的报警案件登记表，现场勘验检查笔录及照片，辨认笔录\n', ''), ('抢劫，盗窃', 'good', '嵩县人民检察院指控：2015年1月23日至25日，被告人李某某连续三天凌晨到嵩县第一高中的2号学生宿\n公诉机关针对上述指控举证如下：被告人李某某的供述与辩解；被害人闫某某、时某某等人陈述；证人王某某证言\n公诉机关认为：被告人李某某以非法占有为目的，多次秘密窃取他人财物，数额较大，再次实施盗窃后为抗拒抓捕\n', ''), ('抢劫，盗窃', 'good', '公诉机关指控：2014年5月6日凌晨1时许，被告人申某经预谋后行至十堰市茅箭区柳林路八一里小区1单元\n', ''), ('故意伤害，掩饰隐瞒犯罪所得犯罪所得收益', 'good', '公诉机关指控，2014年5月13日上午，被告人吴某窜至内蒙古自治区赤峰市，在明知没有合法手续的情况下\n', ''), ('合同诈骗，故意伤害', 'good', '乐陵市人民检察院指控：\n一、××\n2012年6月14日，被告人颜某某以”抵押”借款为目的，在孙某经营的轿车租赁公司租赁一辆黑色现代索塔\n二、××\n2014年7月9日16时许，被告人颜某某和苏某某、王某等人在某某街道办事处某某某东北侧周某某的养殖场\n公诉机关认为，被告人颜某某之行为触犯了《中华人民共和国刑法》××、二百三十四条××之规定，应当以××\n', ''), ('盗窃，容留他人吸毒', 'good', '湖南省辰溪县人民检察院指控：\n一.××\n2014年7月8日至2014年7月10日期间，被告人向某伙同宋某某（另案处理）先后两次窜至辰溪县城、\n二.××\n2014年7月20日，被告人向某明知杨某某、廖某某（均另案处理）系吸毒人员且正从事贩卖毒品，仍允许二\n', ''), ('盗窃，诈骗', 'good', '经审理查明：\n1、2015年8月份的一天，被告人孙某将购买的冥币放到平乡县徐河东村徐某乙处，谎称是其买彩票中奖所得\n2、2016年1月13日，孙某得知赵某丙经常遇到倒霉的事，谎称自己能找“神婆”帮其消灾，但需要赵某丙\n另查明，被害人徐某乙对被告人孙某表示谅解。\n上述事实，被告人孙某在开庭审理过程中亦无异议，并有提取证明、扣押物品清单及照片、赵某丙被骗时放钱小桌\n', ''), ('盗窃，掩饰隐瞒犯罪所得犯罪所得收益', 'good', '江西省寻乌县人民检察院指控，2015年3月21日晚9时许，被告人黎某甲到达寻乌县长宁镇君子坝车之家美\n指控上述事实，公诉机关向本院提出了相关证据，并认为被告人的行为构成××，掩饰、隐瞒犯罪所得罪，提请本\n', ''), ('抢劫，盗窃', 'good', '公诉机关指控，2008年1月间，被告人方士界伙同王某甲、徐某某、王某甲甲（均已判刑）、王某甲乙、王某\n2008年1月19日早，被告人方士界伙同王某甲、徐某某、王某甲甲、王某甲乙、王某甲丙等人再次窜至上述\n被告人方士界于2013年9月5日到公安机关投案。\n针对上述指控，公诉机关向本院提交了相关证据，认为被告人方士界的行为触犯了《中华人民共和国刑法》××、\n', '')]
        data_test = [('交通肇事，掩饰隐瞒犯罪所得犯罪所得收益', 'good', '海丰县人民检察院指控：\n2016年4月8日12时许，被告人苏某无驾驶资格驾驶一辆挂粤Ａ×××××号牌的五某白色小型普通客车在\n被告人苏某所驾驶的五某白色小型普通客车（价值45000元）是其于2015年4月在海丰县公平镇沙场以7\n在法庭审理过程中，公诉人出示了现场、证物及伤情照片，宣读了证明材料等书证、物证以及勘验、辨认笔录、鉴\n公诉机关并提出量刑建议书，认为被告人苏某具有以下量刑情节：1.法定从轻处罚情节：被告人苏某犯罪以后自\n', ''), ('走私贩卖运输制造毒品，无期徒刑', 'good', '济宁市人民检察院起诉指控：2011年至2013年8月，被告人谭1某在广东省广州市番禺区多次将冰毒（甲\n1、2011年下半年的一天，被告人谭1某将25克冰毒卖给刘某。\n2、2011年下半年的一天，被告人谭1某将25克冰毒卖给刘某。\n3、2013年7月，被告人谭1某将70克冰毒卖给刘某。\n4、2013年8月，被告人谭1某将400克冰毒卖给刘某。\n公诉机关就起诉指控的上述犯罪事实，当庭讯问了被告人谭1某，宣读了被告人谭1某的供述和证人刘某、仲某的\n济宁市人民检察院起诉认为，被告人谭1某贩卖冰毒共计520克，其行为触犯了《中华人民共和国刑法》×××\n', ''), ('故意伤害，抢劫', 'good', '黑龙江省哈尔滨市道外区人民检察院指控：\n（一）××\n1995年6月26日18时许，被告人杨1某朋友王某某（另案处理）的朋友白某某（已判刑）在被害人陈某某\n（二）××\n1995年8月23日19时许，被告人杨1某伙同范某某（已判刑）经预谋后，尾随被害人郑某某、杨某甲至哈\n针对上述指控，公诉机关提供了书证案件来源及抓捕经过、被告人杨1某的户籍证明及现实表现；证人王某某、范\n', ''), ('绑架，拐卖妇女儿童', 'good', '福州市仓山区人民检察院指控：\n一、拐卖儿童罪\n2013年1月份至2月份，被告人陈某以打电话及发短信的方式联系其在福州工作的同乡韩某某、柯某某，询问\n二、××\n2013年3月9日至13日，被告人陈某带被害人叶某甲辗转于上海市、宁德市古田县、宁德市蕉城区等地，因\n2013年3月13日20时许，公安机关在宁德市蕉城北路建新宾馆将被告人陈某抓获，现场解救出被害人叶某\n公诉机关认为，被告人陈某的行为已触犯了《中华人民共和国刑法》××、××、××的规定，提请本院以拐卖儿\n', ''), ('诬告陷害，盗窃', 'good', '经审理查明：\n2012年12月15日早上，被告人黄某窜至永康市西城街道排塘村蓝天路830号203室被害人吴某出租房\n2014年10月15日，黄某到案后，对早期胡某带其赌博致其输钱之事心怀不满，遂捏造胡某与其共同盗窃的\n上述事实，被告人黄某在开庭审理过程中亦无异议。并有被告人黄某的供述及辨认笔录、被害人吴某的陈述、证人\n', ''), ('组织强迫引诱容留介绍卖淫，引诱容留介绍卖淫', 'good', '温州市瓯海区人民检察院指控，2012年10月至2014年1月7日，被告人邓某租用温州市瓯海区梧田街道\n', ''), ('寻衅滋事，开设赌场，容留他人吸毒', 'good', '株洲市石峰区人民检察院指控：\n（一）涉嫌××：\n1、2014年12月31日16时许，因怀疑被害人周某在自己老婆面前讲了坏话，被告人郭某甲纠集李某（身\n2、2015年1月底的一天，被告人郭某甲纠集易某（身份不明，在逃）、柳某驾车窜至石峰区北辅道指挥部，\n3、2014年4月12日12时许，被告人郭某甲怀疑其赌场工作人员“宁某”（身份不时）偷了其赌博机里的\n（二）涉嫌××：\n1、2013年年底至2014年8月份，被告人郭某甲在株洲市石峰区横石村柑枝塘安置区的一房间内摆设一台\n2、2014年6月至8月期间，被告人郭某甲伙同“宁某”（身份不明，在逃）在株洲市石峰区啤酒厂附近私房\n3、2014年8、9月份，被告人郭某甲在株洲市田心郊区粮店旁的私房摆设一台8列位捕鱼机和一台6列位捕\n4、2015年2月初至3月10日，被告人郭某甲在株洲市云龙新区职教城青年街一私房内摆设一台10列位捕\n（三）涉嫌容留他人吸毒\n1、2014年10月份的一天，经被告人郭某甲邀请，柳某带了三个朋友去郭某甲位于横石村柑枝塘的渔场子内\n2、2014年10月份的一天，经被告人郭某甲邀请，柳某带了两个朋友去郭某甲位于横石村柑枝塘安置区的渔\n3、2014年，被告人郭某甲在柑枝塘安置房开设捕鱼机赌场期间的一天晚上11点左右，被告人郭某甲邀请吴\n4、距离上次在柑枝塘安置房开设的赌场内吸食毒品一个月后的一天晚上9点左右，被告人郭某甲邀请吴某乙在该\n案发后，被告人郭某甲向公安机关如实供述了上述事实。\n公诉机关认定被告人郭某甲犯××、××、××事实的证据有：1、砍刀、匕首、钱包各一个。2、户籍资料、破\n公诉机关认为，被告人郭某甲多次聚众扰乱公共秩序，任意损毁他人财物，其行为已触犯《中华人民共和国刑法》\n', ''), ('组织强迫引诱容留介绍卖淫，引诱容留介绍卖淫', 'good', '经审理查明，2016年6月30日，被告人杜1某经刘1某（另案处理）介绍到刘1某等人开设在南昌市青云谱\n2016年7月20日晚23时许，南昌市公安局青云谱分局民警在南昌市青云谱区解放西路金悦凯廷宾馆4楼将\n上述事实，被告人杜1某在开庭审理过程中亦无异议，且有金悦凯廷酒店入住押金单，刘3某对外联系照片的名片\n针对起诉书指控的犯罪事实，被告人杜1某无异议且当庭自愿认罪。其辩护人辩称：一、被告人杜1某到该场所上\n针对辩护人的辩称，经审查认为，辩护意见与事实相符，予以采纳。\n', ''), ('非法制造买卖运输邮寄储存枪支弹药爆炸物，非法持有私藏枪支弹药', 'good', '经审理查明，2017年2月7日，平武县公安局在办理其他案件中发现被告人李某某非法持有枪支的案件线索，\n上述事实，被告人在开庭审理过程中亦无异议，并有书证《户籍信息》、《受案登记表》、《立案决定书》、《抓\n', ''), ('走私贩卖运输制造毒品，无期徒刑', 'good', '阜阳市人民检察院指控：2015年10月份左右，被告人代乐某从浙江省慈溪巿一个朋友（基本情况不详）处拿\n为证实指控的犯罪，公诉机关当庭宣读并出示了物证、书证、鉴定意见、检查笔录、毒品称量笔录、证人证言、被\n', ''), ('盗窃，诈骗', 'good', '靖安县人民检察院指控：\n一、××的事实。\n2013年8月18日，被告人蔡某某至靖安县三爪仑乡红星长山组舒某某家中做客，趁受害人舒某某外出时将停\n针对上述事实，公诉机关当庭出示、宣读了如下证据：1、豪剑牌125-A摩托车等物证；2、受案登记表、被\n二、××的事实。\n自2013年8月19日至2014年9月间，被告人蔡某某在靖安县、奉新县干洲镇等地，虚构借钱看望朋友、\n针对上述事实，公诉机关当庭出示、宣读了如下证据：1、建设牌100型助力摩托车等物证；2、受案登记表、\n公诉机关认为，被告人蔡某某以非法占有为目的，秘密窃取他人财物，价值3273元，其行为触犯了《中华人民\n', ''), ('非法拘禁，开设赌场', 'good', '剑阁县人民检察院指控，2014年被害人杜某向梁某夫妇借款，一直没有归还。2015年5月30日被告人梁\n2015年5月31日12时许，被告人梁某决定让杜某某开车载着自己和郑某某、何某某、杜某到杜某老家找杜\n杜某父亲见杜某已受伤怀疑其被人殴打，便于2015年6月1日14时许到普安派出所报案。派出所接到报案后\n公诉机关出示了书证、证人证言，被害人陈述，被告人的供述与辩解等证据。公诉机关认为，被告人梁某为索要财\n', ''), ('开设赌场，容留他人吸毒', 'good', '重庆市万州区人民检察院指控：2014年10月，被告人胡某某与牟某某（已起诉）在重庆市万州区白岩路60\n2014年11月17日至12月29日期间，被告人胡某某与邓某（另案处理）共同在重庆市万州区王牌路33\n对上述指控，公诉机关当庭宣读并出示了户籍资料、抓获经过、鉴定意见书、证人证言、被告人供述等证据，认为\n', ''), ('危险驾驶，妨害公务', 'good', '经审理查明，2013年9月3日21时许，被告人李XX饮酒后驾驶号牌为川AZ2C30的银白色“雪铁龙爱\n上述事实，被告人李XX在庭审中予以认可，且有公诉机关提供的接受刑事案件登记表，情况说明，指认现场笔录\n', ''), ('非法持有私藏枪支弹药，走私贩卖运输制造毒品，非法持有毒品', 'good', '\n经审理查明，原判认定2015年3月上诉人廖某购买手枪一支、子弹五发、枪套一个后携带并乘车至富源县沪', ''), ('信用卡诈骗，职务侵占', 'good', '公诉机关指控：\n一、××\n被告人房某在担任日照盛和投资担保有限公司风险部副经理期间，2013年5月至2014年4月，利用向客户\n1、2011年7月10日，由日照中联汽车销售有限公司提供还款担保，于某从该公司购买瑞麒汽车一辆，首付\n2、2011年11月15日，由日照中联汽车销售有限公司提供还款担保，叶某从该公司购买瑞麒汽车一辆，首\n3、2012年10月15日，由日照盛嘉国际贸易有限公司提供还款担保，孟某从该公司购买捷达汽车一辆，首\n4、2012年8月1日，由日照福士汽车销售有限公司提供还款担保，郭某从该公司购买红旗汽车一辆，首付款\n二、××\n2011年7月5日，被告人房某在交通银行青岛分行办理信用卡一张。2011年12月30日至2012年1\n公诉机关认为，被告人房某身为公司的工作人员，利用职务便利，将本单位的财物非法占为己有，数额较大；以非\n', ''), ('制造贩卖传播淫秽物品，传播淫秽物品', 'good', '克山县人民检察院指控：被告人黄某某自2014年9月份至2015年3月份期间，租用虚拟网络空间开设网址\n公诉机关以被告人的供述、鉴定意见及相关书证证实上述事实，认为被告人黄某某在网上传播淫秽成人游戏、视频\n', ''), ('制造贩卖传播淫秽物品，传播淫秽物品', 'good', '大连市甘井子区人民检察院指控，2013年4月至2013年5月间，被告人王某某为了提升在某网站的级别，\n公诉机关向本院提供了书证案件来源、抓捕经过、常住人口信息、甘井子分局网警大队出具的情况说明、网络截图\n公诉机关认为，被告人王某某的行为触犯了《中华人民共和国刑法》××××之规定，已构成××。提请本院依法\n', ''), ('故意伤害，盗窃', 'good', '金平苗族瑶族傣族自治县人民检察院指控：2013年8月14日13时许，被告人曹1某将、李X经预谋后，骑\n', ''), ('组织强迫引诱容留介绍卖淫，引诱容留介绍卖淫', 'good', '公诉机关指控，2017年3月起，被告人幸某在都江堰市景凤街147号自己经营的无名按摩店内，提供场所供\n被挡获后，被告人幸某如实供述了上述犯罪事实。\n', ''), ('聚众斗殴，走私贩卖运输制造毒品', 'good', '经审理查明，2014年6月间，被告人皇某在连云港市赣榆区赣马镇仲庄村，两次共以人民币200元的价格将\n被告人皇某归案后，如实供述全部犯罪事实。\n上述事实，被告人皇某在开庭审理过程中亦无异议，并有证人尚某、丁某等人的证言、本院（2012）赣少刑初\n关于被告人皇某的辩护人提出被告人系坦白，可以从轻处罚的辩护意见符合本案实际，本院予以采纳。\n', ''), ('组织强迫引诱容留介绍卖淫，引诱容留介绍卖淫', 'good', '经本院审理查明，2011年年底，被告人蔡某某在辽宁省新民市兴隆堡镇本街的“朋乐”歌厅内，介绍卖淫人员\n2012年6月11日，被告人蔡某某在辽宁省新民市兴隆堡镇本街的“朋乐”歌厅内，介绍卖淫人员张某某等二\n2013年11月4日，被告人蔡某某到公安机关投案。\n上述事实，被告人在开庭审理过程中亦无异议，有案件来源、投案自首材料，户籍证明，卖淫人员张某某供述，嫖\n', ''), ('故意伤害，无期徒刑', 'good', '四川省眉山市人民检察院指控，2013年12月22日15时许，被告人罗2某与被害人李4某发生打斗，罗2\n公诉机关认为，被告人罗2某故意伤害他人身体，致人死亡的行为构成××。被告人罗2某案发后主动投案并如实\n附带民事诉讼原告人请求判令被告人赔偿医疗费50000元、死亡赔偿金157900元、被抚养人生活费91\n其诉讼代理人的意见与附民原告人相同，并当庭提交了眉山市人民医院预交金收据3张，证实被害人亲属预交医疗\n', ''), ('故意伤害，无期徒刑', 'good', '浙江省湖州市人民检察院指控，2007年6月2日下午18时许，被告人蒋1某得知其母亲周3某与被害人蒋某\n被害人蒋某某近亲属的代理人认为：1、公诉机关指控的罪名有误，被告人蒋1某的行为应构成故意杀人罪，而不\n附带民事诉讼原告人徐某甲、蒋某甲、蒋某乙、蒋某丙、李某诉请判令被告人蒋1某赔偿医药费1928.5元、\n附带民事诉讼原告人蒋某丁诉请判令被告人蒋1某赔偿医药费2634.94元，误工费1840.63元，护理\n各附带民事诉讼原告人及诉讼代理人分别当庭宣读和出示了被害人的身份证明、医药费发票、门诊病历、诊断证明\n', ''), ('走私贩卖运输制造毒品，容留他人吸毒', 'good', '台州市黄岩区人民检察院指控，一、贩卖毒品\n2013年9月初的一天上午，被告人戴某在台州市黄岩罗曼大酒店内将约1克冰毒以人民币400元的价格贩卖\n为证明上述事实，公诉机关提供的证据有被告人供述和辩解、证人证言及辨认笔某甲\n二、容留他人吸毒\n2013年10月至11月间，被告人戴某先后三次容留袁某在其位于台州市黄岩东城街道东官河路米兰酒店对面\n为证明上述事实，公诉机关提供的证据有物证、证人证言、中国移动通信客户详单，扣押清单、现场检测报告及被\n起诉认为被告人戴某的行为已触犯了《中华人民共和国刑法》××××和××、××之规定，应以贩卖毒品罪、×\n', ''), ('盗窃，非法持有毒品', 'good', '重庆市渝北区人民检察院指控：2013年7月19日19时许，被告人瞿某在重庆市XX区XX街道重庆市XX\n2013的9月2日，被告人瞿某在其亲属的劝解、陪同下到公安机关投案，如实供述其盗窃电脑的事实。到案后\n', ''), ('非法拘禁，赌博', 'good', '绍兴市柯桥区人民检察院指控：\n一、赌博\n2013年12月，被告人楼某伙同他人经事先商量，组织潘某、马某等人在绍兴市柯桥区万商路旁一茶楼和“富\n二、非法拘禁\n2014年3月4日，被告人楼某接受张某委托向王1某索要欠款。次日15时许，被告人楼某伙同傅王3某（另\n', ''), ('诈骗，伪造变造买卖国家机关公文证件印章', 'good', '绵阳高新技术产业开发区人民检察院指控，2015年3月3日至4月8日期间，被告人谭某某以与史某某（本案\n公诉机关认为被告人谭某某采取虚构事实、隐瞒真相的方法骗取公民财物，数额较大的行为构成××，适用《中华\n', ''), ('生产销售伪劣产品，盗窃', 'good', '元某县人民检察院指控，1、2012年6、7月份以来，被告人吴某甲伙同黄某甲、李某甲、张某甲、李某乙（\n2、2014年4至6月间，被告人吴某甲伙同周某某、张某乙（均已判决）经事先共谋，先后到陈某某、吴某乙\n被告人吴某甲的行为构成××、××，请依法判处。\n', ''), ('故意伤害，盗窃', 'good', '福建省莆田市荔城区人民检察院指控：\n一、故意伤害\n2016年12月5日8时许，被告人方某在广东省四会市日丰玉器市场B区82号被害人张某1的摆卖点选购查\n2016年12月13日，被告人方某之子方某与被害人张某1的女儿张某3达成调解，赔偿张某1人民币400\n二、盗窃\n2017年2月27日16时许，被告人方某进入莆田市荔城区黄石镇塘头被害人梁某的租住处，趁梁某不注意，\n2017年3月1日21时许，莆田市公安局荔城分局侦查人员在莆田市荔城区黄石镇惠下村安置房附近抓获被告\n指控上述事实，公诉机关提供了相应的证据。公诉机关认为，被告人方某的行为已触犯《中华人民共和国刑法》×\n', ''), ('故意杀人，无期徒刑', 'good', '河北省邯郸市人民检察院指控：被告人刘2某因家庭琐事与婆母刘某1的长期不和。2015年9月14日凌晨，\n公诉机关认定上述事实的证据有现场勘查笔录、物证、刑事科学技术鉴定、证人证言及被告人供述等。\n公诉机关认为，被告人刘2某因家庭琐事将婆母杀害，其行为触犯了《中华人民共和国刑法》××，应当以××追\n', ''), ('走私贩卖运输制造毒品，非法持有毒品', 'good', '\n经审理查明，原判认定2015年8月5日上诉人刘2某联系云南毒品上线购买毒品，8月10日毒品上线安排', ''), ('非法制造买卖运输邮寄储存枪支弹药爆炸物，非法持有私藏枪支弹药', 'good', '麻栗坡县人民检察院指控：1、被告人卿2某不符合配备、配置枪支条件，擅自持有用射钉器改制的枪支一支，于\n为证明指控事实，公诉机关当庭出示了物证辨认及照片，列举了书证、证人证言、被告人供述与辩解、枪支鉴定书\n公诉机关认为，被告人卿2某非法持有以火药为动力的枪支一支、制造以火药为动力的枪支一支，其行为分别触犯\n', ''), ('盗窃，诈骗', 'good', '洛阳市涧西区人民检察院指控：\n××\n2014年3月底，被告人陈某通过中介租住苗某某位于南昌路壹号城邦小区9号楼1501号房间，签订房屋租\n××\n2014年7月，被告人陈某利用自己保留的壹号城邦9号楼1501号房间钥匙，趁被害人李某某不在家，盗窃\n2014年10月16日凌晨2时许，被告人陈某在洛阳市涧西区花样年华网吧盗窃CPU一个，显卡两块、内存\n2014年10月20日6时许，被告人陈某在洛阳市涧西区西苑路与龙鳞路交叉口华腾网吧盗窃显卡一块、内存\n2014年10月23日、2014年10月25日，被告人陈某两次在洛阳市洛龙区学子街超越休闲网吧内实施\n2014年10月26日、2014年11月10日，被告人陈某两次在涧西区联盟路与武汉路口东100米天幻\n2014年10月29日凌晨4时许，被告人陈某在洛阳市涧西区珠江路心语网吧盗窃117号电脑显卡一块、内\n2014年10月下旬、2014年11月5日22时许，被告人陈某两次在洛阳市涧西区上海市场福昌隆三楼轻\n2014年11月17日被告人陈某父亲陈某某赔偿被害人李某某人民币28000元。\n经鉴定，以上被盗物品（不含相机、黄金戒指、铂金项链）总价值人民币14403.00元。\n公诉机关认为，被告人陈某以非法占有为目的，虚构事实、隐瞒真相，骗取他人财物，数额较大，其行为已经构成\n', ''), ('走私贩卖运输制造毒品，非法持有毒品', 'good', '经再审查明，被告人奚某犯××、贩卖毒品罪的事实、证据与原审查明的相同。\n', ''), ('受贿，巨额财产来源不明', 'good', '吉林省延边朝鲜族自治州人民检察院指控：\n一、受贿犯罪事实\n2006年至2012年，被告人李1某利用担任延吉市委组织部部长、延吉市经济开发区管委会主任、党工委书\n（一）2008年末至2012年初，被告人李1某利用职务便利，接受延边东北燃料有限公司总经理隋某某的请\n（二）2011年，被告人李1某利用职务便利，接受中国白头山实业有限公司总经理金某某的请托，为其协调与\n（三）2011年末至2012年上半年，被告人李1某利用职务便利，接受延边国际贸易大厦经理王某某的请托\n（四）2007年至2011年，被告人李1某利用职务便利，接受延边天一建筑工程有限公司总经理朴某的请托\n（五）2011年，被告人李1某利用职务便利，接受长春市成德实业有限公司董事长贯某某的请托，为该公司在\n（六）2006年至2010年，被告人李1某利用职务便利，接受延吉市东方实业有限公司总经理朴某某的请托\n（七）2011年2月，被告人李1某利用职务便利，帮助时任延边州政府驻北京办事处主任任某某解决资金回流\n（八）2008年至2010年，被告人李1某利用职务便利，接受金3某将开发区管委会搬离租赁韩国人房某某\n（九）2007年至2011年，被告人李1某利用职务便利，接受延边道桥建筑有限公司总经理徐某某的请托，\n（十）2007年，被告人李1某利用职务便利，接受金某某的请托，为金某某承揽延吉经济开发区管委会200\n（十一）2007年，被告人李1某利用职务便利，接受时任延吉市市政工程有限公司总经理徐1某的请托，为该\n（十二）2009年至2011年，被告人李1某利用职务便利，接受延边林业集团物资公司总经理刘某某的请托\n（十三）2011年至2012年，被告人李1某利用职务便利，借与入住延吉市开发区的喜来健实业有限公司制\n（十四）2009年，被告人李1某利用职务便利，接受时任延吉市小营乡长东村书记许某某的请托，为该村在拨\n（十五）2006年至2012年，被告人李1某利用职务便利，为时任延吉市组织部组织科科长田某在职务提拔\n（十六）2008年至2011年，被告人李1某利用职务便利，为时任延吉经济开发区管委会主任助理刘某某在\n（十七）2007年下半年，被告人李1某利用职务便利，接受延边龙盛机动车检车有限公司董事长沈某某的请托\n二、巨额财产来源不明犯罪事实\n被告人李1某及其家庭拥有各类财产折合人民币1836.665241万某。李1某家庭正常支出共计折合人民\n公诉机关就起诉书指控的上述事实向法庭出示了物证、书证、证人证言、被告人李1某供述与辩解等证据，认为，\n', ''), ('盗窃，诈骗', 'good', '南安市人民检察院指控：\n一、××\n1、2015年12月5日21时许，被告人黄3某到南安市溪美纵横机械厂办公楼，爬窗进入二楼黄某的办公室\n2、2015年12月5日23时许，被告人黄3某又到南安市溪美纵横机械厂办公楼，爬窗进入二楼公用办公室\n3、2015年12月6日凌晨1时许，被告人黄3某再次到南安市溪美纵横机械厂办公楼，爬窗进入二楼李某的\n南安市溪美纵横机械厂发现上述人员财物被盗后，经查看该厂监控录像，发现被告人黄3某（化名黄2某）有重大\n2016年8月18日，公安民警在泉州市江南火炬工业园区一店铺抓获被告人黄3某。\n案发后，公安机关向被告人黄3某扣押1条和田玉项链及1个黑色电脑包，后将扣押的上述物品发还被害人李某。\n', ''), ('交通肇事，妨害作证', 'good', '灌云县人民检察院指控，2014年5月12日9时20分许，被告人平某驾驶苏G×××××号中型普通客车载\n事发后，平某弃车逃离现场并找王某顶替，并指使车上的售票员焦某向公安机关提供虚假证明。王某、焦某在公安\n公诉机关认为，应以××、××追究被告人平某刑事责任。\n', ''), ('走私贩卖运输制造毒品，容留他人吸毒', 'good', '公诉机关指控：\n一、贩卖毒品\n2013年12月开始，被告人佘荣志向多名吸毒人员贩卖毒品甲基苯丙胺。\n1.2013年12月中旬一天晚上，被告人佘荣志在吸毒人员唐某某居住503房内，以人民币200元的价格\n2.2014年3月4日21时许，佘荣志驾驶其红色男装摩托车到七星岗公园，并在此处以200元的价格出售\n3.2014年3月4日前后的一天，佘荣志在其居住的301房内，以400元的价格出售给左某某二小包毒品\n4.2014年3月4日晚，吸毒人员陈某杰、李某凤到被告人佘荣志租住301房内，与佘荣志通过赌博抽水的\n2014年3月5日凌晨，佘荣志在高明肉联厂路段被抓获。公安人员在其身上搜获毒品甲基苯丙胺5.55克。\n二、容留他人吸毒\n2014年3月4日晚，吸毒人员陈某杰、李某凤到被告人佘荣志租住的301房出租屋内，与佘荣志赌博抽水1\n', ''), ('信用卡诈骗，拒不支付劳动报酬', 'good', '湖南省新化县人民检察院指控：\n（一）、拒不支付劳动报酬\n2001年，被告人罗1某成立新化县创艺瓷业有限责任公司，并任董事长兼总经理，系公司法定代表人。该公司\n为证明上述事实，公诉机关向本院提交了证人证言、被告人供述、曹家镇政府的情况报告、县人力资源和社会保障\n（二）、××\n被告人罗1某于2010年7月在新化工商银行开办了一张信用额度为50万元的信用卡，并于2010年10月\n为证明上述事实，公诉机关向本院提交了证人证言、被告人供述、办卡资料、账户信息、信用卡交易明细、催收回\n公诉机关认为，被告人罗1某的行为已构成××和××，要求适用刑法××××（四）项、××、××××、××\n', ''), ('故意伤害，故意毁坏财物', 'good', '衡山县人民检察院指控，被告人陈某自2014年12月31日起至2015年1月6日止，多次手持螺纹钢故意\n', ''), ('盗窃，诈骗', 'good', '经审理查明，2013年4月至2014年1月期间，被告人王某甲在南京市鼓楼区、浦口区及广西省南宁市等地\n一、诈骗\n1、2013年4、5月间，被告人王某甲通过互联网认识了张某甲，以谈恋爱结婚为由骗取张某甲的信任。在与\n2、2013年6月间的一天，被告人王某甲通过互联网认识了张某乙，以谈恋爱结婚为由骗取张某乙的信任。在\n3、2013年10月间的一天，被告人王某甲通过互联网认识了徐某乙，以谈恋爱结婚为由骗取徐某乙的信任。\n4、2013年11月间的一天，被告人王某甲通过互联网认识了戴某，以谈恋爱结婚为由骗取戴某的信任。在与\n2014年2月17日，被告人王某甲被公安机关抓获，后如实供述了上述诈骗的犯罪事实。\n上述事实，被告人王某甲在开庭审理过程中无异议，有证人杜某的证言，被害人张某甲、张某乙、张某丙、徐某甲\n二、盗窃\n1、2013年8月间的一天，被告人王某甲在与张某乙交往期间，在张某乙的家中窃得黄金吊坠一个，BENQ\n2、2013年12月至2014年1月间的一天，被告人王某甲在与戴某交往期间，在戴某的家中窃得千足金项\n2014年2月17日，被告人王某甲被公安机关抓获，后如实供述了自己盗窃的犯罪事实。\n上述事实，被告人王某甲在开庭审理过程中无异议，有证人王某乙、李某等人的证言，被害人张某乙、戴某的陈述\n', ''), ('非国家工作人员受贿，职务侵占', 'good', '茂名市茂南区人民检察院指控，\n一、非国家工作人员受贿的犯罪事实\n1、2009年5月，被告人许某甲任某南区新坡镇新城村委会主任和新城村三组组长期间，为谋取不正当利益，\n2、2011年8月，许某甲任某南区新坡镇新城村委会主任和新城村三组组长期间，为谋取不正当利益，利用职\n3、2013年初，许某甲任某南区新坡镇新城村委会主任和新城村三组组长期间，为谋取不正当利益，利用职务\n4、2012年6月，许某甲的女儿出嫁，李某为感谢许某甲在租用和受让土地的帮忙和关照，送给许某甲500\n二、职务侵占的犯罪事实\n2009年至2010年，许某甲利用担任某南区新坡镇新城村委会主任职务之便利，将新城村委会的26300\n公诉机关认为，被告人许某甲无视国法，非法收受他人贿赂，为他人谋取利益，数额较大；其还利用职务上的便利\n', ''), ('组织强迫引诱容留介绍卖淫，引诱容留介绍卖淫', 'good', '阳江市江城区人民检察院指控，被告人任某为牟取私利，于2011年11月份开始租用阳江市江城区漠江路某某\n', ''), ('走私贩卖运输制造毒品，容留他人吸毒', 'good', '万2某市人民检察院指控，（一）贩卖毒品罪\n2013年以来，被告人陈某从其他贩毒人员手中购买毒品（冰毒）后进行贩卖。其采用向杨某某（17岁）、李\n（二）××\n2013年以来，被告人陈某将毒品（冰毒）贩卖给吸毒人员王某甲、李某某、简某某等人及免费提供毒品给吸毒\n公诉机关认为，被告人陈某贩卖毒品，应当以贩卖毒品罪追究刑事责任；被告人陈某非法为他人吸毒提供场所，应\n', ''), ('非法拘禁，盗窃', 'good', '公诉机关指控，2013年12月22日8时许，沂水县振兴花园小区居民张某（已判刑）为向淄博市临朐区敬仲\n公诉机关认为，被告人王某某为索取债务非法拘禁他人，致一人轻伤，其行为侵犯了公民的人身权利，触犯了《中\n', ''), ('故意杀人，无期徒刑', 'good', '广东省佛山市人民检察院指控，2013年12月，被告人朱1某因其妻子被害人谢某某发生婚外情而殴打谢某某\n针对指控的犯罪事实，公诉机关在庭上提供了相应的证据，并据此认为被告人朱1某的行为已触犯《中华人民共和\n', ''), ('伪造变造买卖国家机关公文证件印章，伪造变造买卖武装部队公文证件印章', 'good', '\n经审理查明，原判认定原审被告人李某甲、王某伪造、买卖国家机关、企业、事业单位、人民团体、武装部队证', ''), ('受贿，滥用职权', 'good', '湖北省武汉市武昌区人民检察院指控：被告人戚某在担任武汉市青山区土地整理储备事物中心副主任兼武汉城宇拆\n被告人戚某还于2006年至2013年间，利用负责青山区拆迁工作、工程项目的职务之便，先后收受武汉亿鑫\n一、被告人戚某在负责武汉亿鑫科技发展有限公司拆迁补偿工作过程中，接受李某的请托，利用职务之便，为该公\n1、被告人戚某于2010年春节前的一天，在本市青山区冶金花园的中华洗脚屋内，收受李某给予的贿赂款人民\n2、被告人戚某于2010年十一期间的一天，在本市青山区冶金花园的中华洗脚屋内，收受李某给予的贿赂款人\n3、被告人戚某于2011年春节期间的一天，在本市青山区冶金花园的中华洗脚屋内，收受李某给予的贿赂款人\n4、被告人戚某于2011年十一期间的一天，在本市青山区建一路的家富富桥，收受李某给予的贿赂款人民币3\n5、被告人戚某于2012年春节期间的一天，收受了李某给予的贿赂款人民币3万2某。\n6、被告人戚某于2013年春节期间的一天，在其所住小区内收受了李某给予的贿赂款人民币3万2某。\n二、被告人戚某在负责武汉俊杰置业有限公司厂房收购以及购买该公司开发建设的楼某作为安居房等工作中，接受\n三、被告人戚某在负责本市青山区40、41街坊一期、二期拆除工程等工作中，接受吴某甲的请托，利用职务之\n1、被告人戚某于2006年春节前的一天，收受吴某甲给予的贿赂款2万2某。\n2、被告人戚某于2007年春节前的一天，收受吴某甲给予的贿赂款2万2某。\n3、被告人戚某于2008年春节前的一天，收受吴某甲给予的贿赂款2万2某。\n4、被告人戚某于2008年7、8月的一天，收受吴某甲给予的贿赂款10万2某。\n5、被告人戚某于2009年春节前的一天，收受吴某甲给予的贿赂款2万2某。\n四、被告人戚某在负责本市天兴洲大桥二期厂前段房屋拆除工程等工作中，接受武汉博慧贸易有限公司负责人孙某\n1、被告人戚某于2007年6、7月份的一天，在本市青山区工业大道的青莲酒店内，收受孙某甲给予的贿赂款\n2、被告人戚某于2009年1月的一天，在本市青山区鑫龙潭酒店内，收受孙某甲给予的贿赂款人民币1万2某\n3、被告人戚某于2012年春节前的一天，在本市青山区工业二路孙某甲的办公室内，收受孙某甲给予的贿赂款\n五、被告人戚某在负责本市青山区“旧城改造”中的好宜家宾馆拆迁工作中，接受该宾馆负责人蔡某的请托，为该\n被告人戚某于2013年3月6日在纪检部门通知其接受调查期间，如实交代了上述事实。\n指控上述事实，公诉机关提供有：1、武汉市武昌区人民检察院反渎职侵权局出具的破案经过；2、书证（被告人\n公诉机关认为，被告人戚某身为国家机关工作人员，在依照法律、法规行驶国家行政管理职权过程中，在明知冶南\n', ''), ('故意伤害，故意毁坏财物，寻衅滋事', 'good', '\n经二审审理查明，原审判决认定上诉人刘1某、刘2某犯××、××、××；上诉人刘某甲、马某犯××的事实', ''), ('强迫交易，故意毁坏财物', 'good', '\n经二审审理查明：2013年10月至2014年2月，原审被告人张1某为了阻止货车司机给德州市黑马市场', ''), ('信用卡诈骗，故意伤害', 'good', '古交市人民检察院指控：\n2013年11月19日16时许，被害人薛某在古交市大川西路吊桥附近，因琐事被被告人郝某殴打致伤。经法\n2013年6月25日，被告人郝某在中行古交大川西路支行办理了山西天美信用卡，卡号为62×××05。截\n公诉机关当庭宣读和出示了下列证据：1、被害人薛某的报案材料及陈述；2、被告人郝某的供述；3、法医学鉴\n公诉机关认为，被告人郝某故意伤害他人身体，致人轻伤，其行为已构成××；被告人郝某以非法占有为目的，超\n', ''), ('组织强迫引诱容留介绍卖淫，引诱容留介绍卖淫', 'good', '公诉机关指控，2016年3月份，被告人杜某在临晋镇农贸街上经营一家按摩养生馆。在其经营期间，容留卖淫\n公诉机关认为，被告人杜某目无国法，容留他人卖淫，其行为触犯《中华人民共和国刑法》××之规定，犯罪事实\n', ''), ('走私贩卖运输制造毒品，死刑', 'good', '四川省人民检察院成都铁路运输分院指控:2015年8月18日18时20分许，被告人马某携带三块毒品可疑\n', ''), ('非法拘禁，开设赌场', 'good', '中山市第一市区人民检察院指控：2014年4月1日晚上9时许，被告人周某某为牟取非法利益，接受被害人吴\n', ''), ('故意伤害，盗窃', 'good', '公诉机关指控：\n2014年8月2日凌晨2时许，被告人李某与谢某等人在谢某所居住的芜湖县湾沚镇“名爵KTV”员工宿舍休\n2014年8月22日李某被警方抓获，如实供述犯罪事实。被盗手机已发还被害人谢某。\n', ''), ('故意伤害，无期徒刑', 'good', '贵州省六盘水市人民检察院指控：2013年9月15日11时50分左右，被害人左某某酒后与被告人张3某在\n法医鉴定意见：死者左某某系被单刃类锐器刺伤左胸部乳头上方，进入胸腔，刺破心脏，导致机体急性大量失血、\n', ''), ('危险驾驶，故意伤害', 'good', '平和县人民检察院指控，\n一、故意伤害\n2015年2月4日21时许，因琐事纠纷，被告人林某与吴某甲在平和县小溪镇洲际KTV二楼发生口角，并被\n二、危险驾驶\n2016年4月21日3时许，林某无驾驶资格酒后驾驶未登记号牌摩托车，途经平和县小溪镇北环路与龙溪路交\n公诉机关指控认为，被告人林某故意非法损害他人身体健康，致一人轻伤；醉酒在道路上驾驶机动车，其行为已构\n', ''), ('走私贩卖运输制造毒品，死刑', 'good', '红河哈尼族彝族自治州人民检察院指控：2013年4月21日11时许，被告人李某在江城拿到“岩农”（另案\n针对上述指控，公诉机关向法庭提供了相应的证据，认为被告人李某的行为已触犯《中华人民共和国刑法》×××\n', ''), ('盗窃，抢夺', 'good', '公诉机关指控：\n一、××\n2015年1月份的一天，被告人杨某在其朋友田某某家玩时，趁机盗走田某某的钱包，包内有1280元现金。\n2015年2月份的一天下午，被告人杨某窜至贵阳市花溪区螺丝某赵某某的小卖部，盗走赵某某一个单肩包，包\n2015年3月3日上午6时许，被告人杨某窜至贵阳市花溪区林深路唐某的店面，趁人不备盗走一个挎包，包内\n2015年3月31日上午，被告人杨某窜至贵阳市花溪区湿地公园附近某出租自行车店，趁店主张某某不备，盗\n2015年4月7日，被告人杨某窜至花溪大道上水村路口，盗走路边价值720元的电缆线。\n2015年4月28日，被告人杨某窜至贵阳市花溪区湿地公园抽水房，盗走价值3186元的电缆线。\n二、××\n2015年2月18日17时许，被告人杨某窜至贵阳市花溪区贵州大学北区人行天桥附近，趁行人杨某某不备，\n', ''), ('制造贩卖传播淫秽物品，制作复制出版贩卖传播淫秽物品牟利', 'good', '公诉机关指控称，2013年3月份开始，被告人何某在其经营的本市东城区柏洲边路4号神州通讯店内贩卖淫秽\n据此，公诉机关提供了相关证据，认为被告人何某的行为触犯了《中华人民共和国刑法》××××的规定，构成贩\n', ''), ('故意杀人，无期徒刑', 'good', '广西壮族自治区桂林市人民检察院指控，2015年10月10日13时许，被告人卢2某在家中听到被害人蒋某\n公诉机关认为，被告人卢2某故意非法剥夺他人生命，致一人死亡，一人轻伤，二人轻微伤，其行为已触犯《中华\n', ''), ('组织强迫引诱容留介绍卖淫，引诱容留介绍卖淫', 'good', '经审理查明：\n自2015年9月份以来，被告人王某在义乌市廿三里街道开元北街77号经营“浪情”足浴店，招揽卖淫女，从\n2015年10月10日22时许，黎某容留常某与熊某（均已行政处罚）在该足浴店内以人民币150元的价格\n上述事实，被告人王某在庭审过程中亦无异议，且有违法行为人的证言，证人石某、常某、张某、熊某、刘某的证\n', ''), ('故意伤害，聚众斗殴', 'good', '江苏省东海县人民检察院指控，\n（一）聚众斗殴\n被告人卢某、王1某（已判决）于2013年9月20日22时许，在东海县牛山街道秀水商业街冈某酒吧因敬酒\n案发后，双方已达成赔偿协议。被告人卢某于2014年6月12日自动投案并如实供述犯罪事实。\n（二）故意伤害\n被告人卢某于2013年8月7日，在东海东开发区天籁灯具厂办公室内，因琐事和卢某发生抓打，致卢某鼻骨粉\n被告人卢某于2014年6月12日自动投案并如实供述犯罪事实。\n', ''), ('制造贩卖传播淫秽物品，制作复制出版贩卖传播淫秽物品牟利', 'good', '经审理查明：2016年9月份以来，被告人毛竹从一卖家处以144元价格购得淫秽电影光盘一百二十张，并在\n上述事实，被告人毛竹在庭审过程中亦无异议，且有证人张某的证言，义乌市公安局检查笔录及照片，扣押决定书\n', ''), ('危险驾驶，妨害公务', 'good', '公诉机关指控：\n2016年11月10日20时45分，被告人俞某某酒后驾驶牌号为沪C7XXXX的雪佛兰科帕奇小型普通客\n2016年11月10日，被告人俞某某被公安机关抓获，其到案后如实供述了上述事实。\n', ''), ('故意伤害，赌博', 'good', '杭州市萧山区人民检察院指控：2016年2月24日晚上，被告人倪1某与余某等人在杭州市萧山区浦阳镇桃北\n对上述指控，公诉机关提供了被告人供述、被害人陈述、证人证言、现场勘查材料、鉴定意见及相关书证等证据予\n附带民事诉讼原告人余某以被告人倪1某的犯罪行为对其造成损害为由，要求被告人倪1某赔偿医疗费、护理费、\n针对上述诉讼请求，附带民事诉讼原告人余某提供了书证医疗费票据等证据。\n', ''), ('寻衅滋事，容留他人吸毒', 'good', '公诉机关指控：\n一、寻衅滋事的事实\n2014年9月份的一天，同案人方2某（另案处理）强行向惠来县“东陇汽修厂”老板吴1某吴某借1辆白色“\n经惠来县物价局价格认证中心认定：东陇汽修厂被砸毁的物品共估值人民币2000元。\n二、容留他人吸毒的事实\n被告人方6某因吸食毒品成瘾。自2016年4月份开始，方6某提供毒品及吸毒工具多次容留王2某王某1、陈\n', ''), ('非法采伐毁坏国家重点保护植物，非法收购运输加工出售国家重点保护植物国家重点保护植物制品', 'good', '经审理查明：1、2011年10月期间，被告人朱1某伙同凌某（已判刑）雇请潘某1、潘某2（均已判刑），\n2、2011年11月21日，被告人朱1某伙同黄某（已判刑）等人到宜丰县石花尖垦殖场洪源槽分场与芳溪镇\n被告人朱1某于2014年12月12日到宜丰县森林公安局投案自首。2015年，被告人朱1某因车祸造成严\n上述事实，被告人在开庭审理过程中亦无异议，且有被告人人口信息，归案说明，同案人凌某、黄某、潘某1、潘\n', ''), ('走私贩卖运输制造毒品，容留他人吸毒', 'good', '北京市西城区人民检察院指控：\n被告人刘1某于2015年5月中下旬，在北京市西城区清芷园小区×号楼×号住处附近，以人民币1200元的\n被告人刘1某于2015年1月至8月间，在北京市西城区清芷园小区×号楼×号其住处，多次容留李×吸食冰毒\n被告人刘1某于2015年6月8日19时许，在北京市西城区清芷园小区×号楼×号住处被民警抓获，民警从刘\n针对上述指控的事实，公诉机关提交了书证、证人证言、被告人供述和辩解、鉴定意见、检查笔录、视听资料及其\n', ''), ('组织强迫引诱容留介绍卖淫，引诱容留介绍卖淫', 'good', '榆林市榆阳区人民检察院指控：2015年3月21日22时许，被告人马某某容留、介绍汪某在自己经营的“一\n2015年3月20日22时30分许，被告人马某某介绍汪某在榆阳区梦情缘招待所卖淫一次，获利100元。\n2015年3月20日10时许，被告人马某某介绍高某在自己经营的“一家人”招待所卖淫一次，获利30元。\n2015年3月20日13时许，被告人马某某介绍高某在自己经营的“一家人”招待所卖淫一次，获利30元。\n2015年3月21日22时30分许，被告人马某某介绍高某在榆阳区汉庭酒店卖淫一次，获利200元。\n', ''), ('走私贩卖运输制造毒品，非法持有毒品', 'good', '青神县人民检察院指控称：\n1.被告人邵某贩卖毒品共计5.942克\n（1）2016年12月7日23时50分许，被告人邵某在青神县温馨旅馆外以200元的价格向胡某售毒品甲\n（2）2016年10月24日23时40分许，被告人邵某在青神县家外以100元的价格向张某售毒品甲基苯\n（3）2016年11月8日21时10分许，被告人邵某在青神县家外以100元的价格向张某售毒品甲基苯丙\n（4）2016年11月15日21时30分许，被告人邵某在青神县家外以100元的价格向张某出售毒品甲基\n2.被告人戴1某贩卖毒品6.128克\n（1）2016年12月1日14时，被告人戴1某在欢家门口，以200元的价格向邵某出售2克毒品甲基苯丙\n（2）2016年12月4日中午，被告人戴1某在青神县中意加油站附近，以200元的价格向邵某出售2克毒\n（3）2016年12月8日15时左右，邵某按照民警安排与被告人戴1某电话联系购买毒品，后被告人戴1某\n3.被告人戴1某非法持有毒品205.97克\n2016年12月8日18时许，戴1某按照民警的安排将被告人戴2某约至青神县，后被告人戴2某驾车到相关\n公诉机关认为，被告人邵某、戴1某明知是毒品甲基苯丙胺而多次向他人出售，被告人戴2某明知是毒品甲基苯丙\n', ''), ('故意杀人，抢劫', 'good', '江西省景德镇市人民检察院指控：2004年11月，洪某（已判处××）从外地潜回景德镇市后，纠集被告人汪\n当天早上6时许，汪某、胥某、陈1某、翟某甲四人驾车逃到渡峰坑村附近，汪某打电话向洪某报告了抢劫曹某甲\n公诉机关认定上述指控事实有以下证据：1、抓获经过，刑事判决书等书证；2、证人曹某乙等证言；3、被害人\n公诉机关认为，被告人汪某积极参与持枪抢劫，当场对被害人曹某甲实施暴力，劫取其财物；此外被告人汪某积极\n', ''), ('挪用资金，受贿，滥用职权', 'good', '河南省舞钢市人民检察院指控：\n（一）××\n被告人赵2某在任河南省卫生厅食品安全综合协调与卫生监督处处长期间，明知2009年6月1日《食品安全法\n××\n1、2009年6月至2010年7月，被告人赵2某利用保管卫生监督处监督章的职务便利，超越职权为相关企\n2、2005年、2006年、2010年，被告人赵2某在给郑某、李5某的企业进行产品备案时以支付专家费\n2007年、2010年，被告人赵2某在进行保健食品专家认证过程中，收受张2某现金0.2万某、郑某现金\n被告人赵2某在2006年至2010年中秋节、春节共收受张11某现金4.6万某，给张11某企业办理了《\n被告人赵2某在2003年至2005年春节、中秋节收受岳某1.1万某，2008年至2010年春节收受张\n6、2008年，被告人赵2某利用职务之便，收受郑某现金2万某现金后给任平顶山市卫生局副局长齐某打电话\n7、2011年春节前，被告人赵2某利用职务之便通过郑州市人民医院院长周2某给张8某安排工作，收受张8\n（三）××\n被告人赵2某在担任河南省全民健康促进会健康产品专业委员会主任委员期间，利用保管企业保证金的职务之便，\n公诉机关针对上述指控事实当庭出示了相关物证，书证，证人证言及被告人供述与辩解等证据。依据上述事实和证\n', ''), ('故意伤害，开设赌场', 'good', '公诉机关起诉指控：\n一、××\n2012年8月23日晚，被告人李4某在本区新碶街道大路村镇府路118号暂住房门口见其女友李2某与嫖客\n二、××\n2012年6月至同年8月15日，被告人李4某在王某、张2某、杨1某、刘某（均已判决）等人合伙开设在本\n为证明以上事实，公诉机关向法庭提供了相应的证据。公诉机关认为，被告人李4某故意伤害他人身体，致人重伤\n', ''), ('隐匿故意销毁会计凭证会计帐簿财务会计报告，贪污，挪用公款', 'good', '济南市历城区人民检察院指控：\n一、故意销毁会计凭证、会计账簿罪\n2014年6、7月份，被告人杨某某得知纪律检查部门要对其任职的济南市某林业站的账目等问题进行调查，便\n二、××\n2014年1月21日，被告人杨某某利用职务便利，私自从济南市某镇林业站账外资金中支取公款8万某，借给\n三、××\n被告人杨某某在担任济南市某镇林业站站长期间，采取收入不入帐的手段，于2013年5月将收取的林业站房屋\n公诉机关就起诉指控的上述事实向法庭出示了物证照片、书证、证人证言、被告人供述等证据。公诉机关认为，被\n', ''), ('拒不支付劳动报酬，伪造变造买卖国家机关公文证件印章', 'good', '东莞市第一市区人民检察院起诉指控：\n（一）××\n2014年1月3日，东莞市祥顺运动袋有限公司员工向东莞市人力资源局反映该公司拖欠其2013年11月份\n（二）伪造国家机关印章罪\n2012年6月份，东莞市祥顺运动袋有限公司（以下简称祥顺公司）经营者被告人朱某某为了制作相关的证明材\n针对上述指控的事实，公诉机关当庭宣读并出示了现场勘查笔录、现场图、现场照片，到案经过，户籍证明，东莞\n公诉机关认为，被告人朱某某无视国法，以逃匿的方法逃避支付劳动者的劳动报酬，数额较大，经政府有关部门责\n', ''), ('组织强迫引诱容留介绍卖淫，引诱容留介绍卖淫', 'good', '经审理查明，自2012年9月起，被告人续某受丁某（另案处理）的雇佣，在珠海市香洲区拱北高沙中街28号\n2012年10月23日，被告人续某在上述发廊内，安排卖淫女卢某、周某（另案处理）到拱北金叶酒店110\n同年11月13日，被告人续某在上述发廊内，安排卖淫女王某甲、王某乙（另案处理）到拱北莲花大厦2508\n2014年2月21日，被告人续某主动到公安机关投案。\n上述事实，被告人续某在开庭审理过程中亦无异议，且有经过庭审举证、质证，本院予以确认的证人丁某、何某、\n', ''), ('故意杀人，无期徒刑', 'good', '吉林省四平市人民检察院指控，2013年11月14日22时许，被告人辛某窜至双辽市辽北街东风村被害人李\n', ''), ('受贿，滥用职权', 'good', '长兴县人民检察院指控：\n2007年3月起，被告人张某甲作为合溪水库征地拆迁安置领导小组成员兼办公室副主任，受长兴县槐坎乡人民\n抛渎岗村村民钱某因其房屋在压路机施工时的震动导致裂缝，要求抛渎岗村委会赔偿，村委会经多次协商无果。后\n公诉机关为证实其指控成立，当庭出示或宣读了相关证据材料，并认为被告人张某甲的行为已构成××、××，提\n被告人张某甲提出：1、2012年年初马某交给本人的2万元是马某归还其结欠本人的借款；2、钱某提出开采\n', ''), ('盗伐林木，滥伐林木', 'good', '高要市人民检察院指控被告人冼某于2014年2月至3月14日期间，在未经林业主管部门批准并颁发采伐许可\n经肇庆市林业局林业技术人员鉴定，“罗神岗”山场被采伐林木面积3.24公顷，被采伐松树202株，蓄积4\n', ''), ('合同诈骗，容留他人吸毒', 'good', '天津市滨海新区人民检察院指控，王1某（另案处理）为偿还个人债务，事先与被告人田××及张某（另案处理）\n2015年6月间，被告人田××在天津市滨海新区汉沽温馨家园小区北侧自建平房其经营的无名饭店内，其驾驶\n针对上述指控，公诉机关当庭出示了证人证言、书证、鉴定意见、案件来源、归案经过、被告人主体身份证明等证\n', ''), ('组织强迫引诱容留介绍卖淫，引诱容留介绍卖淫', 'good', '商丘市睢阳区人民检察院指控，2017年3月份，被告人赵某租赁位于商丘市睢阳区文化路与中州路交叉口南路\n针对上述指控，公诉机关当庭出示、宣读了以下证据：1、书证：常住人口信息、抓获经过等；2、证人证言：证\n', ''), ('非法制造买卖运输邮寄储存枪支弹药爆炸物，故意伤害', 'good', '安陆市人民检察院指控\n一、非法制造枪支\n2016年1月期间，被告人吴某甲从工地上捡来一截约一尺长的普通有缝钢管，请同村的徐某帮忙把钢管一头用\n二、故意伤害\n2016年2月7日9时许，被告人吴某甲和其大儿子吴某乙到安陆市东城经济开发区皇廷壹号假日酒店870号\n湖北省安陆市人民检察院认为，被告人吴某甲非法制造具有致伤力的枪支，并用自制的枪支将一人打伤，其行为触\n为支持其指控，公诉机关提供了相应的证据。\n', ''), ('故意伤害，故意毁坏财物，聚众斗殴', 'good', '安徽省滁州市南谯区人民检察院指控：\n被告人李某是滁州市清流监狱的服刑罪犯，其为该监狱第四监区生产组组长。2017年8月8日20时15分许\n2017年8月29日，经滁州市公安司法鉴定中心鉴定，黄某双侧鼻骨骨折的损伤程度为轻伤二级；左眼挫伤的\n公诉机关提供了相应的证据，认为应当以××追究被告人李某的刑事责任。提请本院依法判处被告人李某××至一\n', ''), ('盗窃，掩饰隐瞒犯罪所得犯罪所得收益', 'good', '河北省赵县人民检察院指控，1、2011年4月22日晚，被告人李某甲、张某甲、张某甲在宁晋县苏家庄乡毕\n被告人岳某于2013年9月8日到赵县公安局投案自首。\n', ''), ('寻衅滋事，非法行医', 'good', '永城市人民检察院指控，2010年8月份至2011年4月份，被告人在永登高速公路占地已赔偿到位的情况下\n被告人贺某甲在未取得医师执业资格的情况下，在本市王集镇王集街上、裴桥镇和顺集等地非法开展牙科诊疗活动\n', ''), ('敲诈勒索，掩饰隐瞒犯罪所得犯罪所得收益', 'good', '兴宁市人民检察院指控：\n一、敲诈勒索\n2011年2月至3月期间，陈某君（已判刑）为非法收取过往兴宁境内运载石灰石的货车司机及石灰石窑主的所\n二、掩饰、隐瞒犯罪所得\n2011年5月22日，公安民警在鸿鑫建材店依法扣押了被告人李某煌持有的悬挂粤M07517号牌的蓝色大\n2014年5月6日，被告人李某煌在本市城区被民警抓获。\n', ''), ('盗窃，诈骗', 'good', '经审理查明：一、诈骗事实\n2013年6月底，霍邱县叶集镇柳林村村民刘某带被告人李某到六安4S店看车，但未购买。同年7月1日，李\n上述事实，被告人在开庭审理过程中亦无异议，且有刘某、台某甲、沙某的辨认笔录、辨认照片、被辨认人信息列\n二、盗窃事实\n2013年10月14日中午，被告人李某在霍邱县叶集镇柳树村楼塘组万某甲家×××住×××。后李某到叶集\n上述事实，被告人在开庭审理过程中亦无异议，且有勘验检查笔录、现场方位图，辨认笔录、辨认照片、被辨认人\n公诉机关指控：2013年8月初，李某找到其表舅郭某，自称是安徽宏远工艺品有限公司的法人代表，要在叶集\n公诉机关针对该事实，当庭提供的有扣押物品清单，李某伪造的安徽宏远工艺品有限公司印章、李某个人印章，刘\n', ''), ('制造贩卖传播淫秽物品，制作复制出版贩卖传播淫秽物品牟利', 'good', '上海市浦东新区人民检察院指控：2014年3月21日9时30分许，被告人朱某某在本区惠南镇南门路其经营\n经鉴定，上述涉案的王某某存储卡内的8个视频文件属淫秽文件；从被告人朱某某电脑中查获的视频文件中有22\n被告人朱某某到案后如实供述了上述犯罪事实；案发后，公安机关扣押了计算机1台、存储卡1张及人民币10元\n', ''), ('寻衅滋事，妨害作证', 'good', '浙江省慈溪市人民检察院指控：\n2013年5月7日9时许，因被害人张某东不准被告人黄某的朋友罗某军钓鱼，被告人黄某纠集“一把手”、“\n2013年7月29日，被告人黄某主动至慈溪市公安局桥头派出所投案自首。案发后，被告人黄某已赔偿被害人\n', ''), ('放火，抢劫', 'good', '宁波市江北区人民检察院指控：\n（一）××\n2014年12月27日凌晨2时许，被告人程某在本区中马街道外滩甬江大桥南边引桥下一废弃房屋内采用拳打\n（二）××\n2014年12月27日凌晨2时许，被告人程某在上述地点抢劫被害人孙某未果后，为发泄不满，又用打火机将\n为证明上述指控的犯罪事实，公诉机关向法庭提供了物证、书证、证人证言、被害人陈述、被告人供述与辩解、鉴\n', ''), ('故意伤害，盗窃', 'good', '庆阳市西峰区人民检察院指控，2014年8月23日，被告人闫某窜至庆阳市西峰区长庆南路恒美花园A5幢1\n', ''), ('盗窃，职务侵占', 'good', '上海市宝山区人民检察院指控：\n一、××\n2014年5月9日11时许，被告人王某某至上海市宝山区德都路XXX弄XXX号XXX-XXX室，谎称忘\n二、××\n2014年5月24日、25日，被告人王某某利用其担任上海某某酒店前台收银员的职务便利，在当班期间，将\n', ''), ('受贿，滥用职权', 'good', '利川市人民检察院指控：(一)滥用职权\n2008年至2012年，被告人林某在担任利川市财政局局长兼任利川市全和国资公司（以下简称全和公司）总\n（二）受贿\n2006年至2011年，被告人林某在担任利川市财政局局长兼任某和公司总经理期间，利用职务上的便利，非\n1、2007年10月26日，被告人林某利用职务上的便利，以借为名，要求兰某2(利川市财政局发包的天佛\n2、2010年11月，雷某1筹备在利川市成立利某1小额贷款有限责任公司，并在市工商局取得了企业名称预\n截止案发已逾四年，被告人未归还雷某1个人300万某，也未向利某1小额贷款公司缴纳任何股金，兰某1名下\n公诉机关就起诉指控的事实向本院移送了书证、证人证言、鉴定意见及被告人供述等证据。公诉机关认为，被告人\n', ''), ('组织强迫引诱容留介绍卖淫，引诱容留介绍卖淫', 'good', '公诉机关指控，2014年1月18日23时许，被告人曾某某介绍、容留他人卖淫嫖娼时被岷县公安局民警当场\n对上述指控的事实，公诉机关当庭出示了下列证据：\n1.户籍证明、行政处罚决定书等书证；\n2.证人宋某某、后某某的证言；\n3.被告人曾某某的供述和辩解；\n4.辨认笔录。\n公诉机关认为，被告人曾某某目无国法，非法介绍、容留卖淫并获取利益，其行为触犯了《中华人民共和国刑法》\n', ''), ('合同诈骗，拒不支付劳动报酬', 'good', '沽源县人民检察院指控，2012年9月份至2013年6月份，被告人徐某某承包沽源县玉龙湾宾馆和地下洗浴\n', ''), ('危险驾驶，盗窃', 'good', '公诉机关指控：1、2017年2月10日22时许，被告人苏1某在未取得机动车驾驶证情况下，醉酒驾驶无牌\n', ''), ('走私贩卖运输制造毒品，容留他人吸毒', 'good', '经审理查明：\n（一）贩卖毒品\n1、2014年07月份，被告人盛某某在赵某（另案处理）的授意下，将毒品冰毒5小包（重约3克）在张某分\n2、2014年08月份，被告人盛某某在赵某（另案处理）的授意下，将毒品冰毒3小包（重约1.5克）在张\n（二）容留他人吸毒\n1、2014年04月份的一天，被告人盛某某在汝南县张某姚湾村盛庄自己家中容留张某某、王某某吸食毒品冰\n2、2014年05月底的一天下午，被告人盛某某在汝南县张某姚湾村盛庄自己家中容留张某某、候某某、方某\n3、2014年11月份的一天夜晚，被告人盛某某在汝南县张某姚湾村盛庄自己家中容留张某某、葛某某吸食毒\n上述事实，被告人盛某某在庭审过程中没有异议，并有证人王某某、赵某某、葛某某等人的证言，辨认笔录、汝南\n', ''), ('诈骗，拒不支付劳动报酬', 'good', '北海市银海区人民检察院指控：\n一、合同××\n被告人王1某于2013年10月，在北海市银海区广东南路公园一号楼盘（金某领海郡三期）承包墙体抹灰工程\n二、××\n2013年7月至2014年1月间，被告人王1某在北海市银海区新世纪大道东峰世纪公寓工地承包抹灰工程，\n对上述指控事实，公诉机关提供了相应证据，认为认为被告人王1某以非法占有为目的，在履行合同过程中骗取对\n', '')]

    record_sampled_data = True
    if record_sampled_data:
        dump_excel(data_train, './task4_cail2018_train.xlsx')
        dump_excel(data_test, './task4_cail2018_test.xlsx')

    task = """对输入的案例输出其标签，标签可以有1个或多个。标签包括：非法种植毒品原植物、冒充军人招摇撞骗、非法制造买卖运输储存危险物质、窝藏转移收购销售赃物、破坏计算机信息系统、非法采矿、引诱容留介绍卖淫、强制猥亵侮辱妇女、失火、非法组织卖血、敲诈勒索、抢夺、故意杀人、非法买卖运输携带持有毒品原植物种子幼苗、妨害信用卡管理、徇私舞弊不征少征税款、集资诈骗、组织领导参加黑社会性质组织、非法收购运输盗伐滥伐的林木、非法收购运输加工出售国家重点保护植物国家重点保护植物制品、盗窃、过失损坏武器装备军事设施军事通信、盗伐林木、非法制造买卖运输邮寄储存枪支弹药爆炸物、玩忽职守、走私珍贵动物珍贵动物制品、非法买卖制毒物品、过失致人死亡、非法狩猎、窃取收买非法提供信用卡信息、伪造变造居民身份证、制作复制出版贩卖传播淫秽物品牟利、侵占、提供侵入非法控制计算机信息系统程序工具、非法获取公民个人信息、动植物检疫徇私舞弊、破坏交通工具、非法经营、危险驾驶、窝藏包庇、虚开发票、高利转贷、挪用特定款物、无期徒刑、容留他人吸毒、非法吸收公众存款、非法采伐毁坏国家重点保护植物、强迫卖淫、打击报复证人、强迫劳动、拐骗儿童、走私普通货物物品、编造故意传播虚假恐怖信息、私分国有资产、诽谤、伪造货币、虐待、招收公务员学生徇私舞弊、单位行贿、破坏广播电视设施公用电信设施、伪造变造买卖武装部队公文证件印章、非法捕捞水产品、破坏监管秩序、非法携带枪支弹药管制刀具危险物品危及公共安全、组织卖淫、抢劫、生产销售假药、赌博、票据诈骗、非法占用农用地、走私武器弹药、走私国家禁止进出口的货物物品、行贿、非法生产买卖警用装备、非法拘禁、破坏生产经营、伪证、走私废物、开设赌场、放火、拐卖妇女儿童、伪造倒卖伪造的有价票证、窝藏转移隐瞒毒品毒赃、非法转让倒卖土地使用权、妨害公务、非法持有私藏枪支弹药、投放危险物质、强奸、受贿、过失损坏广播电视设施公用电信设施、伪造变造买卖国家机关公文证件印章、生产销售不符合安全标准的食品、金融凭证诈骗、虚开增值税专用发票用于骗取出口退税抵扣税款发票、职务侵占、聚众斗殴、盗掘古文化遗址古墓葬、妨害作证、引诱教唆欺骗他人吸毒、制造贩卖传播淫秽物品、以危险方法危害公共安全、巨额财产来源不明、徇私枉法、走私、信用卡诈骗、洗钱、帮助毁灭伪造证据、过失以危险方法危害公共安全、死刑、违法发放贷款、非法收购运输出售珍贵濒危野生动物珍贵濒危野生动物制品、劫持船只汽车、聚众冲击国家机关、盗窃侮辱尸体、盗窃抢夺枪支弹药爆炸物危险物质、生产销售伪劣产品、诬告陷害、逃税、扰乱无线电通讯管理秩序、传播淫秽物品、绑架、隐匿故意销毁会计凭证会计帐簿财务会计报告、持有使用假币、重婚、倒卖车票船票、非国家工作人员受贿、强迫他人吸毒、包庇毒品犯罪分子、徇私舞弊不移交刑事案件、非法获取国家秘密、持有伪造的发票、掩饰隐瞒犯罪所得犯罪所得收益、挪用资金、非法持有毒品、盗窃抢夺枪支弹药爆炸物、非法出售发票、贷款诈骗、保险诈骗、收买被拐卖的妇女儿童、招摇撞骗、爆炸、非法制造出售非法制造的发票、协助组织卖淫、故意毁坏财物、诈骗、重大劳动安全事故、拒不执行判决裁定、聚众哄抢、强迫交易、重大责任事故、生产销售伪劣农药兽药化肥种子、伪造公司企业事业单位人民团体印章、拒不支付劳动报酬、脱逃、非法处置查封扣押冻结的财产、合同诈骗、对单位行贿、组织领导传销活动、帮助犯罪分子逃避处罚、聚众扰乱公共场所秩序交通秩序、猥亵儿童、破坏交通设施、侮辱、侵犯著作权、经济犯、破坏电力设备、倒卖文物、非法猎捕杀害珍贵濒危野生动物、聚众扰乱社会秩序、虚报注册资本、非法制造销售非法制造的注册商标标识、假冒注册商标、贪污、出售购买运输假币、对非国家工作人员行贿、销售假冒注册商标的商品、走私贩卖运输制造毒品、交通肇事、骗取贷款票据承兑金融票证、非法行医、污染环境、介绍贿赂、非法进行节育手术、过失投放危险物质、非法生产销售间谍专用器材、过失致人重伤、滥伐林木、串通投标、寻衅滋事、利用影响力受贿、伪造变造金融票证、挪用公款、虐待被监管人、单位受贿、传播性病、危险物品肇事、非法侵入住宅、生产销售有毒有害食品、遗弃、故意伤害、破坏易燃易爆设备、滥用职权、组织强迫引诱容留介绍卖淫、传授犯罪方法"""

    ap = AutoPrompt(
        task,
        data_train,
        'good',
        'bad',
        window_size=len(data_train),
        beam_size=2,
        derive_time=2,
        iteration=2,
        target_inputs=[case[2] for case in data_test],
        target_size=len(data_test),
        split_subtask=False,
        name='CAIL2018',
        show_print=True,
    )

    run_task_1 = False
    if run_task_1:
        # 仅用任务描述作为基线prompt
        ori_prompt_cases = ap.get_cases(
            task,
            len(data_test),
            [case[2] for case in data_test],
            do_variety=False,
            num_consistent=True,
        )
        ap.record.note(('仅用任务描述作为基线prompt的准确率', ap.get_precision(ori_prompt_cases, data_test)))

    run_task_2 = False
    if run_task_2:
        # 将全部训练集数据作为示例的基线prompt
        examples = '\n'.join(['输入：\n{}\n输出：\n{}\n'.format(case[2], case[0]) for case in data_train])

        ori_prompt = """【判例】\n{}\n对输入的案例输出其标签，标签包括：无期徒刑、死刑，以及具体的罪名。""".format(examples)
        fix_prompt_cases = ap.get_cases(
            ori_prompt,
            len(data_test),
            [case[2] for case in data_test],
            do_variety=False,
            num_consistent=True,
        )
        ap.record.note(('将全部训练集数据作为示例的基线prompt的准确率', ap.get_precision(fix_prompt_cases, data_test)))

    run_task_3 = False
    if run_task_3:
        # AutoPrompt输出的prompt
        output_prompts, output_input, output_text = ap.work()
        output_cases = [(ot, '', oi, '') for oi, ot in zip(output_input, output_text)]
        ap.record.note(('优化后的prompt的准确率', ap.get_precision(output_cases, data_test)))
        ap.record.finish()
        dump_excel(output_cases, './CAIL2018/test_rst_{}.xlsx'.format(timestamp(style='min')))

    run_task_4 = False
    if run_task_4:
        # fornax结果为prompt的准确率
        prompt_fornax = """# 角色\n你是一位精准的刑案标签分析师。\n\n# 目标\n根据案件输入的具体内容，从罪行列表中鉴别并指定所有相关的标签。有必要做全面走查，以防遗漏或错误的标签。所指定的每个标签都应直接对应案件中描述的合法或非法行为。\n\n# 技能\n## 技能1：鉴别与列出标签\n1. 当用户提供一则案件输入时，你需要通过仔细地审查输入中描述的行为，从罪行列表中指定对应的标签。\n2. 被指定的标签可能不止一个，所以要全面地、仔细地审查案件以确保不遗漏应该被指定的标签。\n3. 对所有明确提及或强烈暗示的行为指定标签，例如，当只有直接提及或强烈暗示生了无期徒刑的行为时，才应指定'无期徒刑'标签。所以对输入做全面解读是很重要的。\n\n# 约束\n- 只指定明确提及或强烈暗示的行为。不对超出案件描述的事件指定标签，例如，除非案件明确提及了无期徒刑的判决，否则不指定 '无期徒刑' 标签。\n- 尽量避免将非犯罪行为（如无期徒刑）视作法律违反行为的标签。这可能会引入混淆。\n- 不要标注无关的标签。即使在输入中可能暗示有这些行为，也不要做无关的推断或解读。\n- 了解并明确每个罪行标签的含义和范围。\n- 保持对已标注标签的清晰记录，以备后续参考或修改。"""
        ori_prompt_cases = ap.get_cases(
            prompt_fornax,
            len(data_test),
            [case[2] for case in data_test],
            do_variety=False,
            num_consistent=True,
        )
        ap.record.note(('fornax结果为prompt的准确率', ap.get_precision(ori_prompt_cases, data_test)))

        from aitool import dump_excel
        dump_excel(ori_prompt_cases, 'cail2018_fornax.xlsx')
